import tensorflow as tf
from tenorflow import keras as tfk

import tensorflow_probability as tfp
from tensorflow_probability import layers as tfl
from tensorflow_probability import distributions as tfd
from tensorflow_probability import bijectors as tfb
